pygeodesy.ellipsoidalNvector.LatLon

Package pygeodesy :: Module ellipsoidalNvector :: Class LatLon |
[frames] | no frames]

# Class LatLon

                   object --+
                            |
                 named._Named --+
                                |
                 named._NamedBase --+
                                    |
                   object --+       |
                            |       |
                 named._Named --+   |
                                |   |
            ecefLocals._EcefLocal --+
                                    |
                latlonBase.LatLonBase --+
                                        |
            nvectorBase.LatLonNvectorBase --+
                                            |
                   object --+               |
                            |               |
                 named._Named --+           |
                                |           |
                 named._NamedBase --+       |
                                    |       |
                   object --+       |       |
                            |       |       |
                 named._Named --+   |       |
                                |   |       |
            ecefLocals._EcefLocal --+       |
                                    |       |
                latlonBase.LatLonBase --+   |
                                        |   |
    ellipsoidalBase.LatLonEllipsoidalBase --+
                                            |
                                           LatLon

An n-vector-based, ellipsoidal LatLon point.

Instance Methods
deltaTo(self, other, wrap=False, **Ned_and_kwds) Calculate the local delta from this to an other point. |
destinationNed(self, delta) Calculate the destination point using the supplied NED delta from this point. |
distanceTo(self, other, radius=None, wrap=False) Approximate the distance from this to an other point. |
equals(self, other, eps=None) DEPRECATED, use method isequalTo. |
isequalTo(self, other, eps=None) Compare this point with an other point. |
intermediateTo(self, other, fraction, height=None, wrap=False) Return the point at given fraction between this and an other point. |
toCartesian(self, **Cartesian_and_kwds) Convert this point to an `Nvector`-based geodetic point. |
toNvector(self, **Nvector_and_kwds) Convert this point to `Nvector` components, including height. |
Inherited from `nvectorBase.LatLonNvectorBase`: `intersections2`, `others`, `triangulate`, `trilaterate`, `trilaterate5` Inherited from `ellipsoidalBase.LatLonEllipsoidalBase`: `__init__`, `antipode`, `convertDatum`, `convertRefFrame`, `distanceTo2`, `elevation2`, `ellipsoid`, `ellipsoids`, `geoidHeight2`, `intersection3`, `isenclosedBy`, `midpointTo`, `nearestOn`, `parse`, `to3xyz`, `toCss`, `toDatum`, `toEtm`, `toLcc`, `toMgrs`, `toOsgr`, `toRefFrame`, `toTransform`, `toUps`, `toUtm`, `toUtmUps` Inherited from `latlonBase.LatLonBase`: `PointsIter`, `__eq__`, `__ne__`, `__str__`, `bounds`, `boundsOf`, `chordTo`, `circin6`, `circum3`, `circum4_`, `compassAngle`, `compassAngleTo`, `cosineAndoyerLambertTo`, `cosineForsytheAndoyerLambertTo`, `cosineLawTo`, `destinationXyz`, `equals3`, `equirectangularTo`, `euclideanTo`, `flatLocalTo`, `flatPolarTo`, `hartzell`, `haversineTo`, `height4`, `heightStr`, `hubenyTo`, `intersecant2`, `isantipode`, `isantipodeTo`, `isequalTo3`, `latlon2`, `latlon2round`, `latlon_`, `nearestOn6`, `nearestTo`, `normal`, `philam2`, `points`, `points2`, `radii11`, `rhumbAzimuthTo`, `rhumbDestination`, `rhumbDistanceTo`, `rhumbIntersecant2`, `rhumbLine`, `rhumbMidpointTo`, `thomasTo`, `to2ab`, `to3llh`, `toEcef`, `toNormal`, `toStr`, `toVector`, `toVector3d`, `toWm`, `vincentysTo` Inherited from `named._NamedBase`: `__repr__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| Ecef Get the ECEF class (EcefVeness), once.
Inherited from `ellipsoidalBase.LatLonEllipsoidalBase`: `Equidistant`, `convergence`, `datum`, `ellipsoidalLatLon`, `epoch`, `gamma`, `iteration`, `reframe`, `scale` Inherited from `latlonBase.LatLonBase`: `clipid`, `height`, `isEllipsoidal`, `isSpherical`, `isnormal`, `lam`, `lat`, `latlon`, `latlonheight`, `lon`, `phi`, `philam`, `philamheight`, `sphericalLatLon`, `xyz`, `xyz3`, `xyzh` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### deltaTo (self, other, wrap=False, **Ned_and_kwds) |
Calculate the local delta from this to an other point. Arguments: `other` - The other point (LatLon). `wrap` - If `True`, wrap or normalize the `other` point (`bool`). `Ned_and_kwds` - Optional `Ned=Ned class and name=NN` to return delta and other `Ned` keyword arguments. Returns: Delta from this to the other point (`Ned`). Raises: `TypeError` - The `other` point is not LatLon or `Ned` is not an Ned4Tuple nor an Ned nor a DEPRECATED Ned. `ValueError` - If ellipsoids are incompatible. Note: This is a linear delta, unrelated to a geodesic on the ellipsoid.

### destinationNed (self, delta) |
Calculate the destination point using the supplied NED delta from this point. Arguments: `delta` - Delta from this to the other point in the local tangent plane (LTP) of this point (Ned). Returns: Destination point (LatLon). Raises: `TypeError` - If `delta` is not an Ned or a DEPRECATED Ned.

### distanceTo (self, other, radius=None, wrap=False) |
Approximate the distance from this to an other point. Arguments: `other` - The other point (LatLon). `radius` - Mean earth radius, ellipsoid or datum (`meter`, Ellipsoid, Ellipsoid2, Datum or a_f2Tuple), overriding the mean radius `R1` of this point's datum.. `wrap` - If `True`, wrap or normalize and unroll the `other` and angular distance (`bool`). Returns: Distance (`meter`, same units as `radius`). Raises: `TypeError` - The `other` point is not LatLon. `ValueError` - Invalid `radius`.

### equals (self, other, eps=None) |
DEPRECATED, use method isequalTo. Decorators: `@deprecated_method` Overrides: latlonBase.LatLonBase.equals

### isequalTo (self, other, eps=None) |
Compare this point with an other point. Arguments: `other` - The other point (LatLon). `eps` - Optional margin (`float`). Returns: `True` if points are identical, including datum, ignoring height, `False` otherwise. Raises: `TypeError` - The `other` point is not LatLon. `ValueError` - Invalid `eps`. Overrides: latlonBase.LatLonBase.isequalTo See Also: Method `isequalTo3` to include height.

### intermediateTo (self, other, fraction, height=None, wrap=False) |
Return the point at given fraction between this and an other point. Arguments: `other` - The other point (LatLon). `fraction` - Fraction between both points (`scalar`, 0.0 at this to 1.0 at the other point. `height` - Optional height, overriding the fractional height (`meter`). `wrap` - If `True`, wrap or normalize the `other` point (`bool`). Returns: Intermediate point (LatLon). Raises: `TypeError` - The `other` point is not LatLon. Overrides: ellipsoidalBase.LatLonEllipsoidalBase.intermediateTo

### toCartesian (self, **Cartesian_and_kwds) |
Convert this point to an `Nvector`-based geodetic point. Arguments: `Cartesian_and_kwds` - Optional Cartesian, `datum` and other keyword arguments. Use `Cartesian=...` to override this Cartesian class or specify `Cartesian=None`. Returns: The geodetic point (Cartesian) or if `Cartesian is None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `Cartesian` or other `Cartesian_and_kwds`. Overrides: latlonBase.LatLonBase.toCartesian

### toNvector (self, **Nvector_and_kwds) |
Convert this point to `Nvector` components, including height. Arguments: `Nvector_and_kwds` - Optional `Nvector`, `datum` and other keyword arguments. Use `Nvector=...` to override this `Nvector` class or specify `Nvector=None`. Returns: The `n-vector` components (`Nvector`) or if `Nvector` is set to `None`, a Vector4Tuple`(x, y, z, h)`. Raises: `TypeError` - Invalid `Nvector` or other `Nvector_and_kwds`. Overrides: latlonBase.LatLonBase.toNvector

Property Details

### Ecef Get the ECEF class (EcefVeness), once. Get method: Ecef(self) - Get the ECEF class (EcefVeness), once. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.